MageWorx.com
Keywords: Home

- Home
- Submit a Ticket
- Knowledgebase
- News
- Magento Extensions

Login
Remember me

Lost password
Knowledgebase
General (7) Installation (5) Extensions usage (68) Downloads Magento problems (2)
News Categories
News (52) database (1) optimization (1) optimization tips (1) halloween (1) e-commerce (2) online marketing (1) product description (1) MageWorx community manager (1) MageWorx team (1) Facebook contest (1) MageWorx competition (1) Magento customers (1) magento extension (1) brand marketing (1) business promotion (1) pinterest (1) content marketing (1) link building resources (1) seo resources (1) social marketing (1) ecommerce (2) magento merchants (1) mageworx clients (1) 404 error page (1) page not found (1) web design (1) Facebook creative ideas (1) Facebook timeline (1) Timeline cover (1) happy customers page design (1) reviews page design (1) testimonials page design (1) success stories (10) ecommerce trends (1) social shopping (1) magento design (1) magento showcase (1) magento store examples (1) ecommerce tips (2) infographic (1) magento brands (1) digital marketing (1) seo optimization (1) Uncategorized (1) image optimization (1) image seo (1) rich snippets in magento (1) Magento Extensions (3) extended reports extension (1) magento extensions (2) shipping suite extension (1) Magento store (1) mageworx (1) mageworx giveaway (1) how to sell online (1) Magento improvement in 2014 (1) steps to success (1) ecommece in gif (1) magento experts (1) magento experts on twitter (1) halloween magento fun (1) Meet Magento New York (1) easter egg hunt (2) easter game (2) easter (1) magento (4) magento extentsions (1) online contest (1) shoppimon review (1) magento seo (1) seo suite ultimate (1) seo suite ultimate update (1) community management (1) magento community (1) sherrie rohde interview (1) meet magento (2) magento 2.0 (1) mm14ch (1) switzerland (1)
SEARCH
Submit a Ticket Knowledgebase News Magento Extensions
Latest Updates

Oct 29 | Meet Magento Switzerland 2014 Impressions Posted by Vitaly Gonkov on 29 October 2014 04:11 AM
#### Sylvain Rayé, Ben Marks and Guido Jansen are speaking about the first Swiss Meet Magento event and sharing their thoughts on the release of Magento 2.0 Held in the halls of Riverside-Glattfelden Hotel, beautifully located near a leafy spot in the Winterthur region, the first Swiss Meet Magento event gathered around 300 people. 24 keynotes with a large variety of eCommerce and programming topics were delivered by experts in their domain. We have interviewed Sylvain Rayé (one of the main organizers of the event), Ben Marks (a Community Evangelist at Magento) and Guido Jansen (one of the brightest event speakers) and asked their opinions about the conference and thoughts on the upcoming release of Magento 2.0. Sylvain Rayé – Organizer of Meet Magento CH, eCommerce Maker B2B B2C. Magento Expert. OroCRM Akeneo Pioneer “I truly believe that the success of Magento 2.0 largely depends on the commitment of the community. If all the community people support it, adopt it and help to make it better, I’m convinced it will be even more successful than now.” Question: This year you have participated in some of Magento events as a speaker. Now you have tried the role of the event organizer. Does it feel different? Sylvain: Yes, totally. When you just deliver a speech at the conference, it’s one thing. When you organize it, it’s an absolutely different feeling and vision of the event. As an organizer, you have to deal with lots of challenging ‘backstage’ issues, manage various event aspects, make sure everything is in order and under your control. In addition, organizing an event of this type requires cooperation and rapport with lots of different people, so you need to be able to communicate and find time for everyone. As you said, this was the 1st experience in organizing Meet Magento for me. And to be honest, I had to learn a lot to organize the conference the best possible way. Hopefully, me and my team managed to do that. Question: What were the biggest challenges and trouble when organizing Meet Magento event here in Switzerland? Sylvain: Shaping the conference agenda and marketing the event were, perhaps, the most challenging tasks I had to deal with. First, when organizing such a conference, you need to surface the best content, pick up most interesting and trendy topics on eCommerce and Magento development. Second, mainly because Switzerland has a relatively small market, it’s quite difficult to promote the events of such a kind here. In addition to promoting the event online, I had to go to various locations, talk to people, convince them that the conference will be interesting for them and good for their businesses. Question: Almost all of the keynotes at the conference were in English. Why did you decide to choose this language for the German speaking audience? Sylvain: We tried to organize an event that will be interesting both for the local and international businesses. That’s why we chose English as the main language of the conference. However, attracting foreigners to come to the event wasn’t the main reason. You know, there are four national languages in Switzerland: French, German, Italian and Romansh. We wanted to organize Meet Magento that would be interesting for all the Swiss businesses, without an exception. Not only Swiss-German or Swiss-French ones. That’s why we chose English, as it is the international language of communication. Also, in general, English is not a problem for the German speaking people. As you probably know, last week there was Magento Live! in Munich, and it was both in German and in English. No one needed translation actually. Question: You know, everything is changing, and so is Magento. What are your thoughts on the upcoming release of Magento 2.0? Do you believe it will be more successful than its current version? Sylvain: I truly believe that the success of Magento 2.0 largely depends on the commitment of the community. If all the community people support it, adopt it and help to make it better, I’m convinced it will be even more successful than now. That is why we organize Meet Magento events – to get the community actively involved. Question: Do you think that Magento 2.0 can reshape the eCommerce landscape? Sylvain: You know, to reshape something, you need to have a different vision of it. At the moment it’s hard to say what changes Magento 2.0 will bring. Some technical improvements still need to be made and some important points concerning the framework and features need to be clarified. But I believe that if Magento manages to introduce a product that will be easy-to-use for an average shop owner and a customer (who just want to get the best experience and don’t care much about technical aspects), it will definitely have a success. We thank Sylvain for the interview and wish him good luck with organizing more Magento events in Switzerland. #### A cool fact about Sylvain Rayé: changes hair style every season. Ben Marks, Community Evangelist at Magento “From the developer standpoint, Magento 2.0 is a cleaner code base with a clearer, more consistent architecture. So basically this is one of the things that facilitates testing. I think the ability to write and alter code and know that you are not negatively affecting anything else in the system is vital, especially in eCommerce.” Question: Please share your impressions about the 1st Meet Magento Switzerland event. Ben: If you go to a lot of Meet Magento events, which I’m lucky to be able to do, there’s always a constant level of quality everywhere. But there are also distinct features in each region, which I think make all of them successful. Talking about this conference, it’s great to see the 1st time event with so many people having business, going to the talks and getting valuable Magento experience. Question: Which of Meet Magento events was the brightest and the most memorable this year? Ben: Unfortunately, I haven’t been able to visit each conference. I have attended the events in Milan (Italy), New York, Romania, Brazil and … Switzerland obviously. Romania was good for me, because it was my first time there. You know, even flying over the Carpathian was magic. Also, for me, as an outsider, was surprising to learn how big the Magento community was there, how much business was going on in this region and how high the level of production was. Also, I enjoyed Brazil a lot. It was a smaller event though, but the Brazilian hospitality was just amazing. Question: Ok. And the next group of questions is about the thing everybody in the community is talking about now – Magento 2.0. What do you personally expect from the platform upgrade? Ben: From the developer standpoint, Magento 2.0 is a cleaner code base with a clearer, more consistent architecture. So basically this is one of the things that facilitates testing. I think the ability to write and alter code and know that you are not negatively affecting anything else in the system is vital especially in eCommerce. So the testability for me is probably one of the most important things about Magento 2.0. Question: As it has been recently announced, the developer demo version of Magento 2.0 is coming this December, right? Ben: Yes, true. But note that it’s not like Magento 1. Mainly because this time we are making our own framework. There are plenty of good PHP networks out there, but we decided to make our own. We are following some of the PHP framework interoperability group, PHP FIG; following some industry standards, PHP standard recommendations – PSR, and we are using Composer. We know that Magento 2.0 is going to be playing like a lot of PHP networks and a lot of other PHP apps. So our main task for now is to make sure that it all works well. Right now we are working on the platform. And in December we are putting out our best idea of what Magento 2.0 is. Then we collect all the feedback from developers, roll it up and in March the platform should be compete. After that, we are going to start the merchant side of it. That’s when we’ll take the final version of the framework and go through all the eCommerce functionality in Magento. This is already happening a little bit, but later we’ll be primarily focusing on this. Basically, what we want to do is to make all the functionality of Magento 1 exist in Magento 2.0, but with all the proper refactoring. For example, right now if you go to Magento and look at Sales – Order object, it has more than 20 dependencies in its constructor. This is really not ideal, and it means that this class is doing to much and hard and expensive to test. After all this job is done and the platform gets polished, we will launch its final version during the last quarter of 2015. When Magento 2.0 is released, there will be the Enterprise version, the Community version, and we will support Magento 1 for the next three years. We thank Ben for the interview and wish him good luck with the community and Magento 2.0 next year. #### A cool fact about Ben Marks: Ben has the coolest Mac in the whole Magento community Guido Jansen – Conversion Manager for Comparison International at Sanoma, speaker. “I’m sure the new version of Magento will be popular. It has a lot of potential for the platform and the ecosystem in general. However, this is unlikely to become popular at once – the transition stage from the current version to a newer one will take some time.” Question: You have attended lots of Meet Magento events this year. Which one was the best in your opinion? Guido: Well, it’s hard to say and single out the best one, as each Meet Magento conference is unique. But, you know, I love seeing the events happening for the 1st time, like it is right here. It’s always great to discover new places, new people, emerging markets – all that is real fun. Question: You know, everyone in the community is talking about Magento 2.0. What are your personal expectations from the new version of the platform? Guido: Well, I personally expect that it will go stable in the next 20 years. Question: Do you believe that Magento 2.0 is capable of reshaping the whole eCommerce landscape? Guido: It’s hard say for now. I’m sure the new version of the platform will be popular. It has a lot of potential for the platform and the ecosystem in general. However, this is unlikely to happen at once – the transition stage from the current version to a newer one will take some time. People need to master it, get used to it. Now we all are just in an early adaptation phase, there’s still a long road ahead of us, and we all need to learn what kind of beast Magento 2.0 is. Question: Guido, we loved your presentation is was just amazing (follow the link to watch it). Could you share more tips on online persuasion with our blog readers? Guido: Sure. Question: When talking about reciprocation in eCommerce, you mentioned the fact that in order to attract people, you need to provide some type of enticement for them. That can be a free month of subscription to your service, a free app, a free e-Book, whatever. But I guess that these days there are tons of such free stuff online, and people just take it for granted. They lost their interest to such things. Is there any way to revive their interest to things they are used to get free of charge? Guido: Yes. Let me draw an example. Here, at the conference, anyone can get a free pen. And no one cares about the name of the company written on it. Everyone expects to get a free pen, pencil, notebook, and things like that. But this stuff is not really special to them. Because it’s impersonal. Make it personal, and people will love it again. You can generate a personalized discount coupon, a pen with somebody’s name, etc. Remember the latest Coca-Cola campaign? But note that it also won’t work if you trade free stuff for something. For instance, you ask to subscribe to your newsletter to get a free book. In this case you aren’t offering a book for free actually, you are trading it. Question: Talking about trading, you know that now lots of companies offer free stuff, but when you actually get it, you discover that in order to get the functionality or the features you need, you have to shell out. For example, downloading a free app that does almost nothing unless you unlock the paid features. Is such type of deliberate deceiving ok, or it can hurt your business? Guido: Well, it’s all about ethics actually. Personally, I don’t like this tactics. I believe that you should inform people before they get/download something that has limited/restricted functionality. Each offer of such a type should be properly labeled to tell people what they can actually get. No more, no less. Otherwise, you have a very little chance to engage with these people later. Question: I can’t but agree. And the last question: in your speech you said a lot about different means of persuasion. You know, now we are living in a visual world. Do you think that images can work as a more effective means of persuasion than text? Guido: I think both can work well. It really depends on a type of a website and a customer. I did some tests with chaining images and text, and I should say that both can bring good results. I haven’t seen any A/B testing with videos. And frankly speaking, I doubt that video is a good option here (as it distracts people). But text can be one of the options you can change videos with. We thank Guido for the interview and wish him good luck with and a bigger number of bight conference performances next year. #### Cool facts about Guido: Guido is an avoid Coca-Cola fan. ### Good bye Switzerland! Untill next time! Read more »
Sep 24 | Meet Magento Switzerland 2014 – Learn. Share. Connect. Posted by Natalie Pavlovskaya on 24 September 2014 04:26 AM
### The leading Magento eCommerce Community Conference is arriving in Zurich, Switzerland. Being the world’s famous eCommerce conference, with 8 years of experience in 11 countries, Meet Magento will take place in Zurich on October, 24 for the first time. The leading specialists and experts from the entire ecosystem: merchants, service providers, agencies and developers will present their knowledge and share their experience. The event promises to deliver great speeches about: • Magento 2 • revenue improvements • inbound marketing • code quality and productivity • B2B/B2C • psychology in eCommerce The conference is an excellent opportunity to encounter the whole Magento community, learn more about the latest eCommerce trends, exchange knowledge, establish new contacts and find great benefits for your business. Meet Magento Switzerland 2014 expects about 300 attendees from different European counties, so it’s an excellent chance to grow your business network in Switzerland and Europe. ### Conference Highlights The event’s highlights include: • Morning Magento run (still need to be confirmed) • Opening Keynote from ricardo.ch • 24 conferences with a large variety of topics done by experts in their domain • Day closing with Magento Community Manager Ben Marks • Magento Doctors Booth from the Firegento Association • Networking After Party • Magento Bowling Contest • Famous international & Swiss Speakers • Magento Hackathon on 25th & 26th October ### Speakers An impressive line-up of the keynote speakers has been assembled for the 1st Meet Magento Swedish edition. ### ### Tickets and Location The ticket sale has now been opened. You can get your pass to the conference HERE Meet Magento Switzerland will be held in the halls of Riverside-Glattfelden Hotel, beautifully located near a leafy spot in the Winterthur region. P.S. By the way, the MageWorx team is also planning to visit the event. So if you want to learn more about us, exchange business cards or discuss any type of cooperation, we can meet up there. Being a Bronze Sponsor and the conference media partner, we will be covering the event on Twitter, Facebook and on our blog. Read more »
Aug 21 | MEET MAGENTO NEW YORK: FROM INSPIRATION TO ACTION Posted by Natalie Pavlovskaya on 21 August 2014 10:19 AM
For entrepreneurs, developers and service providing agencies in and around Magento industry, Meet Magento events are an essential way to get up to speed on the latest tech and ecommerce trends, do business and share ideas within the community, find potential customers and partners,and just have lots of fun! Meet Magento New York is the first ever Meet Magento conference held in the United States. Mark down September 22-23, 2014 in your calendar, get a ticket with the 20% discount (code: MgWrxMM) and pack your bags. It’s going to be epic! ## The Conference Be prepared for two fully-packed days of networking events, presentations of the industry leading speakers, tons of insights, “Speed Dating” business sessions and a Hackathon. What is more, the event offers a great opportunity to take your business to the international arena. You can meet lots of new people from all over the world, listen to the Magento brightest minds, connect with the most interesting community members and find new friends. The event takes place at Digital Sandbox – 55 Broad Street, located in the heart of the Financial District. stromvergleich ## Speaker Hall of Fame Meet Magento NY will bring together the most passionate and purpose-driven minds. They’re inspiring, smart, fun and creative. They are exactly who will give you the big picture of Magento and eCommerce. The content of the conference ranges from the little search box keynotes and online persuasion ideas to the talks on the trend disrupting eCommerce and killing businesses and how to work with Magento extension providers. ## Stay Tuned - #MM14NY ## and don’t forget to get tickets 20% off – your discount code is MgWrxMM Read more »
Apr 18 | EASTER EGG HUNT WINNER ANNOUNCED Posted by Natalie Pavlovskaya on 18 April 2014 11:06 AM
MageWorx Easter Egg Hunt is officially over. Thanks to everyone who took part in our Easter egg hunt! We hope you had great time and lots of fun. And the lucky winner is…. *DRUMROLL* Maurice Hein (mhei***@gmail.com). CONGRATULATIONS!!! But that’s not all! Everybody who took part in the contest, but didn’t win, will get a special consolation prize! Check your email boxes for more info. Thanks for being with us and HAPPY EASTER !!! Read more »
Apr 16 | Join MageWorx Easter Egg Hunt Game! Posted by Natalie Pavlovskaya on 16 April 2014 10:06 AM
Heyya folks! The spring is in full swing and so is the Easter season! The nature is shaking off the blanket of snow, making room for green fields and blooming valleys. Catch the spring spirit! Grab a basket and join our Easter Egg Hunt craze! ## What’s in Store For You? Awesome prizes valued at $400 provided by the leading Magento extensions provider. A chance to win top-flight Magento modules, installation or customization services for your store extensions, and more! Lots of fun, laughs and an amazing Egg Hunt adventure! ## How Can Take Part? Anyone and your grandma can! There are absolutely no restrictions. Everyone is very welcome! ## The Rules The rules are dead simple. There are 7 eggs hidden or 7 different pages of our website. Each egg is marked with a sticker. On each sticker you can see the number and the word. 7 words make up a phrase that is our Great Egg Hunt Сlue. Your task is to find the 7 eggs and put the words on them in the right order (from 1 to 7). To make it even easier, you can use the map below: put each found egg into the corresponding spot to make up our Easter phrase. When done, drop us line with the CLUE, and we will save your email in our database. When the contest is over, we will randomly choose the lucky winner. The winner will get any MageWorx extension (or extensions), installation or customization services at the price of $400! The Egg Hunt starts today and will last till Friday 04, 18. Hurry up! No more time to waste! Jump to this page to find the 1-st egg! Read more »

View all news
Magento Extensions developed by MageWorx